@@ -1,6 +1,6 @@
 from .kidney import Kidney
 from .monochromator import Monochromator
-from .samplse import Sample
+from .sample import Sample
 from . import virtualMACS
 from .scripting import get_kidney_params
 from .scripting import get_mono_params
